{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.AccountingService where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LocalBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.FinancialService
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AccountingService
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place

-- | Accountancy business.                As a LocalBusiness it can be        described as a provider of one or more        Service(s).
--
--   [@id@] AccountingService
--
--   [@label@] Accounting Service
--
--   [@comment@] Accountancy business.        <br/><br/>        As a <a href=\"http://schema.org/LocalBusiness\">LocalBusiness</a> it can be        described as a <a href=\"http://schema.org/provider\">provider</a> of one or more        <a href=\"http://schema.org/Service\">Service(s)</a>.      
--
--   [@ancestors@] @'Thing','Organization','LocalBusiness','FinancialService','AccountingService','Thing','Place','LocalBusiness','FinancialService'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'FinancialService'@
--
--   [@url@] <http://schema.org/AccountingService>
data AccountingService = AccountingService { branchCode :: BranchCode
                                           , currenciesAccepted :: CurrenciesAccepted
                                           , openingHours :: OpeningHours
                                           , paymentAccepted :: PaymentAccepted
                                           , priceRange :: PriceRange
                                           , address :: Address
                                           , aggregateRating :: AggregateRating
                                           , alumni :: Alumni
                                           , areaServed :: AreaServed
                                           , award :: Award
                                           , brand :: Brand
                                           , contactPoint :: ContactPoint
                                           , department :: Department
                                           , dissolutionDate :: DissolutionDate
                                           , duns :: Duns
                                           , email :: Email
                                           , employee :: Employee
                                           , event :: Event
                                           , faxNumber :: FaxNumber
                                           , founder :: Founder
                                           , foundingDate :: FoundingDate
                                           , foundingLocation :: FoundingLocation
                                           , globalLocationNumber :: GlobalLocationNumber
                                           , hasOfferCatalog :: HasOfferCatalog
                                           , hasPOS :: HasPOS
                                           , isicV4 :: IsicV4
                                           , legalName :: LegalName
                                           , location :: Location
                                           , logo :: Logo
                                           , makesOffer :: MakesOffer
                                           , member :: Member
                                           , memberOf :: MemberOf
                                           , naics :: Naics
                                           , numberOfEmployees :: NumberOfEmployees
                                           , owns :: Owns
                                           , parentOrganization :: ParentOrganization
                                           , review :: Review
                                           , seeks :: Seeks
                                           , subOrganization :: SubOrganization
                                           , taxID :: TaxID
                                           , telephone :: Telephone
                                           , vatID :: VatID
                                           , additionalProperty :: AdditionalProperty
                                           , containedInPlace :: ContainedInPlace
                                           , containsPlace :: ContainsPlace
                                           , geo :: Geo
                                           , hasMap :: HasMap
                                           , openingHoursSpecification :: OpeningHoursSpecification
                                           , photo :: Photo
                                           , additionalType :: AdditionalType
                                           , alternateName :: AlternateName
                                           , description :: Description
                                           , image :: Image
                                           , mainEntityOfPage :: MainEntityOfPage
                                           , name :: Name
                                           , potentialAction :: PotentialAction
                                           , sameAs :: SameAs
                                           , url :: Url
                                           }
                         deriving (Show, Read, Eq, Typeable)

instance MetaData AccountingService where
  _label         = const "Accounting Service"
  _comment_plain = const "Accountancy business.                As a LocalBusiness it can be        described as a provider of one or more        Service(s)."
  _comment       = const "Accountancy business.        <br/><br/>        As a <a href=\"http://schema.org/LocalBusiness\">LocalBusiness</a> it can be        described as a <a href=\"http://schema.org/provider\">provider</a> of one or more        <a href=\"http://schema.org/Service\">Service(s)</a>.      "
  _url           = const "http://schema.org/AccountingService"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.FinancialService.FinancialService)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.AccountingService.AccountingService)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.FinancialService.FinancialService)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.FinancialService.FinancialService)]