{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.AchieveAction where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LoseAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TieAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.WinAction

-- | The act of accomplishing something via previous efforts. It is an instantaneous action rather than an ongoing process.
--
--   [@id@] AchieveAction
--
--   [@label@] Achieve Action
--
--   [@comment@] The act of accomplishing something via previous efforts. It is an instantaneous action rather than an ongoing process.
--
--   [@ancestors@] @'Thing','Action'@
--
--   [@subtypes@] @'LoseAction','TieAction','WinAction'@
--
--   [@supertypes@] @'Action'@
--
--   [@url@] <http://schema.org/AchieveAction>
data AchieveAction = AchieveAction { actionStatus :: ActionStatus
                                   , agent :: Agent
                                   , endTime :: EndTime
                                   , error :: Error
                                   , instrument :: Instrument
                                   , location :: Location
                                   , object :: Object
                                   , participant :: Participant
                                   , result :: Result
                                   , startTime :: StartTime
                                   , target :: Target
                                   , additionalType :: AdditionalType
                                   , alternateName :: AlternateName
                                   , description :: Description
                                   , image :: Image
                                   , mainEntityOfPage :: MainEntityOfPage
                                   , name :: Name
                                   , potentialAction :: PotentialAction
                                   , sameAs :: SameAs
                                   , url :: Url
                                   }
                     deriving (Show, Read, Eq, Typeable)

instance MetaData AchieveAction where
  _label         = const "Achieve Action"
  _comment_plain = const "The act of accomplishing something via previous efforts. It is an instantaneous action rather than an ongoing process."
  _comment       = const "The act of accomplishing something via previous efforts. It is an instantaneous action rather than an ongoing process."
  _url           = const "http://schema.org/AchieveAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.LoseAction.LoseAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TieAction.TieAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.WinAction.WinAction)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)]