{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.AggregateOffer where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Offer

-- | When a single product is associated with multiple offers (for example, the same pair of shoes is offered by different merchants), then AggregateOffer can be used.
--
--   [@id@] AggregateOffer
--
--   [@label@] Aggregate Offer
--
--   [@comment@] When a single product is associated with multiple offers (for example, the same pair of shoes is offered by different merchants), then AggregateOffer can be used.
--
--   [@ancestors@] @'Thing','Intangible','Offer'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Offer'@
--
--   [@url@] <http://schema.org/AggregateOffer>
data AggregateOffer = AggregateOffer { highPrice :: HighPrice
                                     , lowPrice :: LowPrice
                                     , offerCount :: OfferCount
                                     , offers :: Offers
                                     , acceptedPaymentMethod :: AcceptedPaymentMethod
                                     , addOn :: AddOn
                                     , advanceBookingRequirement :: AdvanceBookingRequirement
                                     , aggregateRating :: AggregateRating
                                     , areaServed :: AreaServed
                                     , availability :: Availability
                                     , availabilityEnds :: AvailabilityEnds
                                     , availabilityStarts :: AvailabilityStarts
                                     , availableAtOrFrom :: AvailableAtOrFrom
                                     , availableDeliveryMethod :: AvailableDeliveryMethod
                                     , businessFunction :: BusinessFunction
                                     , category :: Category
                                     , deliveryLeadTime :: DeliveryLeadTime
                                     , eligibleCustomerType :: EligibleCustomerType
                                     , eligibleDuration :: EligibleDuration
                                     , eligibleQuantity :: EligibleQuantity
                                     , eligibleRegion :: EligibleRegion
                                     , eligibleTransactionVolume :: EligibleTransactionVolume
                                     , gtin12 :: Gtin12
                                     , gtin13 :: Gtin13
                                     , gtin14 :: Gtin14
                                     , gtin8 :: Gtin8
                                     , includesObject :: IncludesObject
                                     , ineligibleRegion :: IneligibleRegion
                                     , inventoryLevel :: InventoryLevel
                                     , itemCondition :: ItemCondition
                                     , itemOffered :: ItemOffered
                                     , mpn :: Mpn
                                     , offeredBy :: OfferedBy
                                     , price :: Price
                                     , priceCurrency :: PriceCurrency
                                     , priceSpecification :: PriceSpecification
                                     , priceValidUntil :: PriceValidUntil
                                     , review :: Review
                                     , seller :: Seller
                                     , serialNumber :: SerialNumber
                                     , sku :: Sku
                                     , validFrom :: ValidFrom
                                     , validThrough :: ValidThrough
                                     , warranty :: Warranty
                                     , additionalType :: AdditionalType
                                     , alternateName :: AlternateName
                                     , description :: Description
                                     , image :: Image
                                     , mainEntityOfPage :: MainEntityOfPage
                                     , name :: Name
                                     , potentialAction :: PotentialAction
                                     , sameAs :: SameAs
                                     , url :: Url
                                     }
                      deriving (Show, Read, Eq, Typeable)

instance MetaData AggregateOffer where
  _label         = const "Aggregate Offer"
  _comment_plain = const "When a single product is associated with multiple offers (for example, the same pair of shoes is offered by different merchants), then AggregateOffer can be used."
  _comment       = const "When a single product is associated with multiple offers (for example, the same pair of shoes is offered by different merchants), then AggregateOffer can be used."
  _url           = const "http://schema.org/AggregateOffer"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Offer.Offer)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Offer.Offer)]