{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.BodyOfWater where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Landform
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Canal
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LakeBodyOfWater
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.OceanBodyOfWater
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Pond
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Reservoir
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.RiverBodyOfWater
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.SeaBodyOfWater
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Waterfall

-- | A body of water, such as a sea, ocean, or lake.
--
--   [@id@] BodyOfWater
--
--   [@label@] Body of Water
--
--   [@comment@] A body of water, such as a sea, ocean, or lake.
--
--   [@ancestors@] @'Thing','Place','Landform'@
--
--   [@subtypes@] @'Canal','LakeBodyOfWater','OceanBodyOfWater','Pond','Reservoir','RiverBodyOfWater','SeaBodyOfWater','Waterfall'@
--
--   [@supertypes@] @'Landform'@
--
--   [@url@] <http://schema.org/BodyOfWater>
data BodyOfWater = BodyOfWater { additionalProperty :: AdditionalProperty
                               , address :: Address
                               , aggregateRating :: AggregateRating
                               , branchCode :: BranchCode
                               , containedInPlace :: ContainedInPlace
                               , containsPlace :: ContainsPlace
                               , event :: Event
                               , faxNumber :: FaxNumber
                               , geo :: Geo
                               , globalLocationNumber :: GlobalLocationNumber
                               , hasMap :: HasMap
                               , isicV4 :: IsicV4
                               , logo :: Logo
                               , openingHoursSpecification :: OpeningHoursSpecification
                               , photo :: Photo
                               , review :: Review
                               , telephone :: Telephone
                               , additionalType :: AdditionalType
                               , alternateName :: AlternateName
                               , description :: Description
                               , image :: Image
                               , mainEntityOfPage :: MainEntityOfPage
                               , name :: Name
                               , potentialAction :: PotentialAction
                               , sameAs :: SameAs
                               , url :: Url
                               }
                   deriving (Show, Read, Eq, Typeable)

instance MetaData BodyOfWater where
  _label         = const "Body of Water"
  _comment_plain = const "A body of water, such as a sea, ocean, or lake."
  _comment       = const "A body of water, such as a sea, ocean, or lake."
  _url           = const "http://schema.org/BodyOfWater"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Landform.Landform)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Canal.Canal)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LakeBodyOfWater.LakeBodyOfWater)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.OceanBodyOfWater.OceanBodyOfWater)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Pond.Pond)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Reservoir.Reservoir)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.RiverBodyOfWater.RiverBodyOfWater)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.SeaBodyOfWater.SeaBodyOfWater)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Waterfall.Waterfall)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Landform.Landform)]