{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.CommentAction where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.InteractAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CommunicateAction

-- | The act of generating a comment about a subject.
--
--   [@id@] CommentAction
--
--   [@label@] Comment Action
--
--   [@comment@] The act of generating a comment about a subject.
--
--   [@ancestors@] @'Thing','Action','InteractAction','CommunicateAction'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'CommunicateAction'@
--
--   [@url@] <http://schema.org/CommentAction>
data CommentAction = CommentAction { resultComment :: ResultComment
                                   , about :: About
                                   , inLanguage :: InLanguage
                                   , recipient :: Recipient
                                   , actionStatus :: ActionStatus
                                   , agent :: Agent
                                   , endTime :: EndTime
                                   , error :: Error
                                   , instrument :: Instrument
                                   , location :: Location
                                   , object :: Object
                                   , participant :: Participant
                                   , result :: Result
                                   , startTime :: StartTime
                                   , target :: Target
                                   , additionalType :: AdditionalType
                                   , alternateName :: AlternateName
                                   , description :: Description
                                   , image :: Image
                                   , mainEntityOfPage :: MainEntityOfPage
                                   , name :: Name
                                   , potentialAction :: PotentialAction
                                   , sameAs :: SameAs
                                   , url :: Url
                                   }
                     deriving (Show, Read, Eq, Typeable)

instance MetaData CommentAction where
  _label         = const "Comment Action"
  _comment_plain = const "The act of generating a comment about a subject."
  _comment       = const "The act of generating a comment about a subject."
  _url           = const "http://schema.org/CommentAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.InteractAction.InteractAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CommunicateAction.CommunicateAction)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.CommunicateAction.CommunicateAction)]