{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ConfirmAction where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.InteractAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CommunicateAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.InformAction

-- | The act of notifying someone that a future event/action is going to happen as expected.Related actions:CancelAction: The antonym of ConfirmAction.
--
--   [@id@] ConfirmAction
--
--   [@label@] Confirm Action
--
--   [@comment@] The act of notifying someone that a future event/action is going to happen as expected.<p>Related actions:</p><ul><li><a href=\"http://schema.org/CancelAction\">CancelAction</a>: The antonym of ConfirmAction</li></ul>.
--
--   [@ancestors@] @'Thing','Action','InteractAction','CommunicateAction','InformAction'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'InformAction'@
--
--   [@url@] <http://schema.org/ConfirmAction>
data ConfirmAction = ConfirmAction { event :: Event
                                   , about :: About
                                   , inLanguage :: InLanguage
                                   , recipient :: Recipient
                                   , actionStatus :: ActionStatus
                                   , agent :: Agent
                                   , endTime :: EndTime
                                   , error :: Error
                                   , instrument :: Instrument
                                   , location :: Location
                                   , object :: Object
                                   , participant :: Participant
                                   , result :: Result
                                   , startTime :: StartTime
                                   , target :: Target
                                   , additionalType :: AdditionalType
                                   , alternateName :: AlternateName
                                   , description :: Description
                                   , image :: Image
                                   , mainEntityOfPage :: MainEntityOfPage
                                   , name :: Name
                                   , potentialAction :: PotentialAction
                                   , sameAs :: SameAs
                                   , url :: Url
                                   }
                     deriving (Show, Read, Eq, Typeable)

instance MetaData ConfirmAction where
  _label         = const "Confirm Action"
  _comment_plain = const "The act of notifying someone that a future event/action is going to happen as expected.Related actions:CancelAction: The antonym of ConfirmAction."
  _comment       = const "The act of notifying someone that a future event/action is going to happen as expected.<p>Related actions:</p><ul><li><a href=\"http://schema.org/CancelAction\">CancelAction</a>: The antonym of ConfirmAction</li></ul>."
  _url           = const "http://schema.org/ConfirmAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.InteractAction.InteractAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CommunicateAction.CommunicateAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.InformAction.InformAction)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.InformAction.InformAction)]