{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ConsumeAction where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.DrinkAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.EatAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.InstallAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ListenAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ReadAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.UseAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ViewAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.WatchAction

-- | The act of ingesting information/resources/food.
--
--   [@id@] ConsumeAction
--
--   [@label@] Consume Action
--
--   [@comment@] The act of ingesting information/resources/food.
--
--   [@ancestors@] @'Thing','Action'@
--
--   [@subtypes@] @'DrinkAction','EatAction','InstallAction','ListenAction','ReadAction','UseAction','ViewAction','WatchAction'@
--
--   [@supertypes@] @'Action'@
--
--   [@url@] <http://schema.org/ConsumeAction>
data ConsumeAction = ConsumeAction { expectsAcceptanceOf :: ExpectsAcceptanceOf
                                   , actionStatus :: ActionStatus
                                   , agent :: Agent
                                   , endTime :: EndTime
                                   , error :: Error
                                   , instrument :: Instrument
                                   , location :: Location
                                   , object :: Object
                                   , participant :: Participant
                                   , result :: Result
                                   , startTime :: StartTime
                                   , target :: Target
                                   , additionalType :: AdditionalType
                                   , alternateName :: AlternateName
                                   , description :: Description
                                   , image :: Image
                                   , mainEntityOfPage :: MainEntityOfPage
                                   , name :: Name
                                   , potentialAction :: PotentialAction
                                   , sameAs :: SameAs
                                   , url :: Url
                                   }
                     deriving (Show, Read, Eq, Typeable)

instance MetaData ConsumeAction where
  _label         = const "Consume Action"
  _comment_plain = const "The act of ingesting information/resources/food."
  _comment       = const "The act of ingesting information/resources/food."
  _url           = const "http://schema.org/ConsumeAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.DrinkAction.DrinkAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.EatAction.EatAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.InstallAction.InstallAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ListenAction.ListenAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ReadAction.ReadAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.UseAction.UseAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ViewAction.ViewAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.WatchAction.WatchAction)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)]