{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Continent where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Landform

-- | One of the continents (for example, Europe or Africa).
--
--   [@id@] Continent
--
--   [@label@] Continent
--
--   [@comment@] One of the continents (for example, Europe or Africa).
--
--   [@ancestors@] @'Thing','Place','Landform'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Landform'@
--
--   [@url@] <http://schema.org/Continent>
data Continent = Continent { additionalProperty :: AdditionalProperty
                           , address :: Address
                           , aggregateRating :: AggregateRating
                           , branchCode :: BranchCode
                           , containedInPlace :: ContainedInPlace
                           , containsPlace :: ContainsPlace
                           , event :: Event
                           , faxNumber :: FaxNumber
                           , geo :: Geo
                           , globalLocationNumber :: GlobalLocationNumber
                           , hasMap :: HasMap
                           , isicV4 :: IsicV4
                           , logo :: Logo
                           , openingHoursSpecification :: OpeningHoursSpecification
                           , photo :: Photo
                           , review :: Review
                           , telephone :: Telephone
                           , additionalType :: AdditionalType
                           , alternateName :: AlternateName
                           , description :: Description
                           , image :: Image
                           , mainEntityOfPage :: MainEntityOfPage
                           , name :: Name
                           , potentialAction :: PotentialAction
                           , sameAs :: SameAs
                           , url :: Url
                           }
                 deriving (Show, Read, Eq, Typeable)

instance MetaData Continent where
  _label         = const "Continent"
  _comment_plain = const "One of the continents (for example, Europe or Africa)."
  _comment       = const "One of the continents (for example, Europe or Africa)."
  _url           = const "http://schema.org/Continent"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Landform.Landform)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Landform.Landform)]