{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.CreditCard where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Enumeration
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PaymentMethod

-- | A credit or debit card type as a standardized procedure for transferring the monetary amount for a purchase.    Commonly used values:    http://purl.org/goodrelations/v1#AmericanExpress     http://purl.org/goodrelations/v1#DinersClub     http://purl.org/goodrelations/v1#Discover     http://purl.org/goodrelations/v1#JCB     http://purl.org/goodrelations/v1#MasterCard     http://purl.org/goodrelations/v1#VISA
--
--   [@id@] CreditCard
--
--   [@label@] Credit Card
--
--   [@comment@] A credit or debit card type as a standardized procedure for transferring the monetary amount for a purchase.<br/>    Commonly used values:<br/><br/>    http://purl.org/goodrelations/v1#AmericanExpress <br/>    http://purl.org/goodrelations/v1#DinersClub <br/>    http://purl.org/goodrelations/v1#Discover <br/>    http://purl.org/goodrelations/v1#JCB <br/>    http://purl.org/goodrelations/v1#MasterCard <br/>    http://purl.org/goodrelations/v1#VISA <br/>        
--
--   [@ancestors@] @'Thing','Intangible','Enumeration','PaymentMethod'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'PaymentMethod'@
--
--   [@url@] <http://schema.org/CreditCard>
data CreditCard = CreditCard { supersededBy :: SupersededBy
                             , additionalType :: AdditionalType
                             , alternateName :: AlternateName
                             , description :: Description
                             , image :: Image
                             , mainEntityOfPage :: MainEntityOfPage
                             , name :: Name
                             , potentialAction :: PotentialAction
                             , sameAs :: SameAs
                             , url :: Url
                             }
                  deriving (Show, Read, Eq, Typeable)

instance MetaData CreditCard where
  _label         = const "Credit Card"
  _comment_plain = const "A credit or debit card type as a standardized procedure for transferring the monetary amount for a purchase.    Commonly used values:    http://purl.org/goodrelations/v1#AmericanExpress     http://purl.org/goodrelations/v1#DinersClub     http://purl.org/goodrelations/v1#Discover     http://purl.org/goodrelations/v1#JCB     http://purl.org/goodrelations/v1#MasterCard     http://purl.org/goodrelations/v1#VISA"
  _comment       = const "A credit or debit card type as a standardized procedure for transferring the monetary amount for a purchase.<br/>    Commonly used values:<br/><br/>    http://purl.org/goodrelations/v1#AmericanExpress <br/>    http://purl.org/goodrelations/v1#DinersClub <br/>    http://purl.org/goodrelations/v1#Discover <br/>    http://purl.org/goodrelations/v1#JCB <br/>    http://purl.org/goodrelations/v1#MasterCard <br/>    http://purl.org/goodrelations/v1#VISA <br/>        "
  _url           = const "http://schema.org/CreditCard"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PaymentMethod.PaymentMethod)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.PaymentMethod.PaymentMethod)]