{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.DDxElement where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalIntangible

-- | An alternative, closely-related condition typically considered later in the differential diagnosis process along with the signs that are used to distinguish it.
--
--   [@id@] DDxElement
--
--   [@label@] D Dx Element
--
--   [@comment@] An alternative, closely-related condition typically considered later in the differential diagnosis process along with the signs that are used to distinguish it.
--
--   [@ancestors@] @'Thing','MedicalEntity','MedicalIntangible'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'MedicalIntangible'@
--
--   [@url@] <http://schema.org/DDxElement>
data DDxElement = DDxElement { diagnosis :: Diagnosis
                             , distinguishingSign :: DistinguishingSign
                             , code :: Code
                             , guideline :: Guideline
                             , medicineSystem :: MedicineSystem
                             , recognizingAuthority :: RecognizingAuthority
                             , relevantSpecialty :: RelevantSpecialty
                             , study :: Study
                             , additionalType :: AdditionalType
                             , alternateName :: AlternateName
                             , description :: Description
                             , image :: Image
                             , mainEntityOfPage :: MainEntityOfPage
                             , name :: Name
                             , potentialAction :: PotentialAction
                             , sameAs :: SameAs
                             , url :: Url
                             }
                  deriving (Show, Read, Eq, Typeable)

instance MetaData DDxElement where
  _label         = const "D Dx Element"
  _comment_plain = const "An alternative, closely-related condition typically considered later in the differential diagnosis process along with the signs that are used to distinguish it."
  _comment       = const "An alternative, closely-related condition typically considered later in the differential diagnosis process along with the signs that are used to distinguish it."
  _url           = const "http://schema.org/DDxElement"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalIntangible.MedicalIntangible)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalIntangible.MedicalIntangible)]