{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.DanceGroup where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PerformingGroup

-- | A dance group—for example, the Alvin Ailey Dance Theater or Riverdance.
--
--   [@id@] DanceGroup
--
--   [@label@] Dance Group
--
--   [@comment@] A dance group—for example, the Alvin Ailey Dance Theater or Riverdance.
--
--   [@ancestors@] @'Thing','Organization','PerformingGroup'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'PerformingGroup'@
--
--   [@url@] <http://schema.org/DanceGroup>
data DanceGroup = DanceGroup { address :: Address
                             , aggregateRating :: AggregateRating
                             , alumni :: Alumni
                             , areaServed :: AreaServed
                             , award :: Award
                             , brand :: Brand
                             , contactPoint :: ContactPoint
                             , department :: Department
                             , dissolutionDate :: DissolutionDate
                             , duns :: Duns
                             , email :: Email
                             , employee :: Employee
                             , event :: Event
                             , faxNumber :: FaxNumber
                             , founder :: Founder
                             , foundingDate :: FoundingDate
                             , foundingLocation :: FoundingLocation
                             , globalLocationNumber :: GlobalLocationNumber
                             , hasOfferCatalog :: HasOfferCatalog
                             , hasPOS :: HasPOS
                             , isicV4 :: IsicV4
                             , legalName :: LegalName
                             , location :: Location
                             , logo :: Logo
                             , makesOffer :: MakesOffer
                             , member :: Member
                             , memberOf :: MemberOf
                             , naics :: Naics
                             , numberOfEmployees :: NumberOfEmployees
                             , owns :: Owns
                             , parentOrganization :: ParentOrganization
                             , review :: Review
                             , seeks :: Seeks
                             , subOrganization :: SubOrganization
                             , taxID :: TaxID
                             , telephone :: Telephone
                             , vatID :: VatID
                             , additionalType :: AdditionalType
                             , alternateName :: AlternateName
                             , description :: Description
                             , image :: Image
                             , mainEntityOfPage :: MainEntityOfPage
                             , name :: Name
                             , potentialAction :: PotentialAction
                             , sameAs :: SameAs
                             , url :: Url
                             }
                  deriving (Show, Read, Eq, Typeable)

instance MetaData DanceGroup where
  _label         = const "Dance Group"
  _comment_plain = const "A dance group—for example, the Alvin Ailey Dance Theater or Riverdance."
  _comment       = const "A dance group—for example, the Alvin Ailey Dance Theater or Riverdance."
  _url           = const "http://schema.org/DanceGroup"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PerformingGroup.PerformingGroup)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.PerformingGroup.PerformingGroup)]