{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.DeliveryChargeSpecification where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.StructuredValue
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PriceSpecification

-- | The price for the delivery of an offer using a particular delivery method.
--
--   [@id@] DeliveryChargeSpecification
--
--   [@label@] Delivery Charge Specification
--
--   [@comment@] The price for the delivery of an offer using a particular delivery method.
--
--   [@ancestors@] @'Thing','Intangible','StructuredValue','PriceSpecification'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'PriceSpecification'@
--
--   [@url@] <http://schema.org/DeliveryChargeSpecification>
data DeliveryChargeSpecification = DeliveryChargeSpecification { appliesToDeliveryMethod :: AppliesToDeliveryMethod
                                                               , areaServed :: AreaServed
                                                               , eligibleRegion :: EligibleRegion
                                                               , ineligibleRegion :: IneligibleRegion
                                                               , eligibleQuantity :: EligibleQuantity
                                                               , eligibleTransactionVolume :: EligibleTransactionVolume
                                                               , maxPrice :: MaxPrice
                                                               , minPrice :: MinPrice
                                                               , price :: Price
                                                               , priceCurrency :: PriceCurrency
                                                               , validFrom :: ValidFrom
                                                               , validThrough :: ValidThrough
                                                               , valueAddedTaxIncluded :: ValueAddedTaxIncluded
                                                               , additionalType :: AdditionalType
                                                               , alternateName :: AlternateName
                                                               , description :: Description
                                                               , image :: Image
                                                               , mainEntityOfPage :: MainEntityOfPage
                                                               , name :: Name
                                                               , potentialAction :: PotentialAction
                                                               , sameAs :: SameAs
                                                               , url :: Url
                                                               }
                                   deriving (Show, Read, Eq, Typeable)

instance MetaData DeliveryChargeSpecification where
  _label         = const "Delivery Charge Specification"
  _comment_plain = const "The price for the delivery of an offer using a particular delivery method."
  _comment       = const "The price for the delivery of an offer using a particular delivery method."
  _url           = const "http://schema.org/DeliveryChargeSpecification"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.StructuredValue.StructuredValue)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PriceSpecification.PriceSpecification)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.PriceSpecification.PriceSpecification)]