{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.DeliveryEvent where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Event

-- | An event involving the delivery of an item.
--
--   [@id@] DeliveryEvent
--
--   [@label@] Delivery Event
--
--   [@comment@] An event involving the delivery of an item.
--
--   [@ancestors@] @'Thing','Event'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Event'@
--
--   [@url@] <http://schema.org/DeliveryEvent>
data DeliveryEvent = DeliveryEvent { accessCode :: AccessCode
                                   , availableFrom :: AvailableFrom
                                   , availableThrough :: AvailableThrough
                                   , hasDeliveryMethod :: HasDeliveryMethod
                                   , aggregateRating :: AggregateRating
                                   , attendee :: Attendee
                                   , doorTime :: DoorTime
                                   , duration :: Duration
                                   , endDate :: EndDate
                                   , eventStatus :: EventStatus
                                   , inLanguage :: InLanguage
                                   , location :: Location
                                   , offers :: Offers
                                   , organizer :: Organizer
                                   , performer :: Performer
                                   , previousStartDate :: PreviousStartDate
                                   , recordedIn :: RecordedIn
                                   , review :: Review
                                   , startDate :: StartDate
                                   , subEvent :: SubEvent
                                   , superEvent :: SuperEvent
                                   , typicalAgeRange :: TypicalAgeRange
                                   , workFeatured :: WorkFeatured
                                   , workPerformed :: WorkPerformed
                                   , additionalType :: AdditionalType
                                   , alternateName :: AlternateName
                                   , description :: Description
                                   , image :: Image
                                   , mainEntityOfPage :: MainEntityOfPage
                                   , name :: Name
                                   , potentialAction :: PotentialAction
                                   , sameAs :: SameAs
                                   , url :: Url
                                   }
                     deriving (Show, Read, Eq, Typeable)

instance MetaData DeliveryEvent where
  _label         = const "Delivery Event"
  _comment_plain = const "An event involving the delivery of an item."
  _comment       = const "An event involving the delivery of an item."
  _url           = const "http://schema.org/DeliveryEvent"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Event.Event)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Event.Event)]