{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.EmergencyService where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LocalBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.EmergencyService
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.FireStation
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Hospital
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PoliceStation

-- | An emergency service, such as a fire station or ER.
--
--   [@id@] EmergencyService
--
--   [@label@] Emergency Service
--
--   [@comment@] An emergency service, such as a fire station or ER.
--
--   [@ancestors@] @'Thing','Organization','LocalBusiness','EmergencyService','Thing','Place','LocalBusiness'@
--
--   [@subtypes@] @'FireStation','Hospital','PoliceStation'@
--
--   [@supertypes@] @'LocalBusiness'@
--
--   [@url@] <http://schema.org/EmergencyService>
data EmergencyService = EmergencyService { branchCode :: BranchCode
                                         , currenciesAccepted :: CurrenciesAccepted
                                         , openingHours :: OpeningHours
                                         , paymentAccepted :: PaymentAccepted
                                         , priceRange :: PriceRange
                                         , address :: Address
                                         , aggregateRating :: AggregateRating
                                         , alumni :: Alumni
                                         , areaServed :: AreaServed
                                         , award :: Award
                                         , brand :: Brand
                                         , contactPoint :: ContactPoint
                                         , department :: Department
                                         , dissolutionDate :: DissolutionDate
                                         , duns :: Duns
                                         , email :: Email
                                         , employee :: Employee
                                         , event :: Event
                                         , faxNumber :: FaxNumber
                                         , founder :: Founder
                                         , foundingDate :: FoundingDate
                                         , foundingLocation :: FoundingLocation
                                         , globalLocationNumber :: GlobalLocationNumber
                                         , hasOfferCatalog :: HasOfferCatalog
                                         , hasPOS :: HasPOS
                                         , isicV4 :: IsicV4
                                         , legalName :: LegalName
                                         , location :: Location
                                         , logo :: Logo
                                         , makesOffer :: MakesOffer
                                         , member :: Member
                                         , memberOf :: MemberOf
                                         , naics :: Naics
                                         , numberOfEmployees :: NumberOfEmployees
                                         , owns :: Owns
                                         , parentOrganization :: ParentOrganization
                                         , review :: Review
                                         , seeks :: Seeks
                                         , subOrganization :: SubOrganization
                                         , taxID :: TaxID
                                         , telephone :: Telephone
                                         , vatID :: VatID
                                         , additionalProperty :: AdditionalProperty
                                         , containedInPlace :: ContainedInPlace
                                         , containsPlace :: ContainsPlace
                                         , geo :: Geo
                                         , hasMap :: HasMap
                                         , openingHoursSpecification :: OpeningHoursSpecification
                                         , photo :: Photo
                                         , additionalType :: AdditionalType
                                         , alternateName :: AlternateName
                                         , description :: Description
                                         , image :: Image
                                         , mainEntityOfPage :: MainEntityOfPage
                                         , name :: Name
                                         , potentialAction :: PotentialAction
                                         , sameAs :: SameAs
                                         , url :: Url
                                         }
                        deriving (Show, Read, Eq, Typeable)

instance MetaData EmergencyService where
  _label         = const "Emergency Service"
  _comment_plain = const "An emergency service, such as a fire station or ER."
  _comment       = const "An emergency service, such as a fire station or ER."
  _url           = const "http://schema.org/EmergencyService"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.EmergencyService.EmergencyService)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.FireStation.FireStation)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Hospital.Hospital)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PoliceStation.PoliceStation)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)]