{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.FindAction where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CheckAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.DiscoverAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TrackAction

-- | The act of finding an object.Related actions:SearchAction: FindAction is generally lead by a SearchAction, but not necessarily.
--
--   [@id@] FindAction
--
--   [@label@] Find Action
--
--   [@comment@] The act of finding an object.<p>Related actions:</p><ul><li><a href=\"http://schema.org/SearchAction\">SearchAction</a>: FindAction is generally lead by a SearchAction, but not necessarily</li></ul>.
--
--   [@ancestors@] @'Thing','Action'@
--
--   [@subtypes@] @'CheckAction','DiscoverAction','TrackAction'@
--
--   [@supertypes@] @'Action'@
--
--   [@url@] <http://schema.org/FindAction>
data FindAction = FindAction { actionStatus :: ActionStatus
                             , agent :: Agent
                             , endTime :: EndTime
                             , error :: Error
                             , instrument :: Instrument
                             , location :: Location
                             , object :: Object
                             , participant :: Participant
                             , result :: Result
                             , startTime :: StartTime
                             , target :: Target
                             , additionalType :: AdditionalType
                             , alternateName :: AlternateName
                             , description :: Description
                             , image :: Image
                             , mainEntityOfPage :: MainEntityOfPage
                             , name :: Name
                             , potentialAction :: PotentialAction
                             , sameAs :: SameAs
                             , url :: Url
                             }
                  deriving (Show, Read, Eq, Typeable)

instance MetaData FindAction where
  _label         = const "Find Action"
  _comment_plain = const "The act of finding an object.Related actions:SearchAction: FindAction is generally lead by a SearchAction, but not necessarily."
  _comment       = const "The act of finding an object.<p>Related actions:</p><ul><li><a href=\"http://schema.org/SearchAction\">SearchAction</a>: FindAction is generally lead by a SearchAction, but not necessarily</li></ul>."
  _url           = const "http://schema.org/FindAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.CheckAction.CheckAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.DiscoverAction.DiscoverAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TrackAction.TrackAction)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)]