{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.GovernmentService where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Service

-- | A service provided by a government organization, e.g. food stamps, veterans benefits, etc.
--
--   [@id@] GovernmentService
--
--   [@label@] Government Service
--
--   [@comment@] A service provided by a government organization, e.g. food stamps, veterans benefits, etc.
--
--   [@ancestors@] @'Thing','Intangible','Service'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Service'@
--
--   [@url@] <http://schema.org/GovernmentService>
data GovernmentService = GovernmentService { serviceOperator :: ServiceOperator
                                           , aggregateRating :: AggregateRating
                                           , areaServed :: AreaServed
                                           , availableChannel :: AvailableChannel
                                           , award :: Award
                                           , category :: Category
                                           , hasOfferCatalog :: HasOfferCatalog
                                           , hoursAvailable :: HoursAvailable
                                           , offers :: Offers
                                           , provider :: Provider
                                           , providerMobility :: ProviderMobility
                                           , review :: Review
                                           , serviceOutput :: ServiceOutput
                                           , serviceType :: ServiceType
                                           , additionalType :: AdditionalType
                                           , alternateName :: AlternateName
                                           , description :: Description
                                           , image :: Image
                                           , mainEntityOfPage :: MainEntityOfPage
                                           , name :: Name
                                           , potentialAction :: PotentialAction
                                           , sameAs :: SameAs
                                           , url :: Url
                                           }
                         deriving (Show, Read, Eq, Typeable)

instance MetaData GovernmentService where
  _label         = const "Government Service"
  _comment_plain = const "A service provided by a government organization, e.g. food stamps, veterans benefits, etc."
  _comment       = const "A service provided by a government organization, e.g. food stamps, veterans benefits, etc."
  _url           = const "http://schema.org/GovernmentService"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Service.Service)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Service.Service)]