{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.InfectiousDisease where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalCondition

-- | An infectious disease is a clinically evident human disease resulting from the presence of pathogenic microbial agents, like pathogenic viruses, pathogenic bacteria, fungi, protozoa, multicellular parasites, and prions. To be considered an infectious disease, such pathogens are known to be able to cause this disease.
--
--   [@id@] InfectiousDisease
--
--   [@label@] Infectious Disease
--
--   [@comment@] An infectious disease is a clinically evident human disease resulting from the presence of pathogenic microbial agents, like pathogenic viruses, pathogenic bacteria, fungi, protozoa, multicellular parasites, and prions. To be considered an infectious disease, such pathogens are known to be able to cause this disease.
--
--   [@ancestors@] @'Thing','MedicalEntity','MedicalCondition'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'MedicalCondition'@
--
--   [@url@] <http://schema.org/InfectiousDisease>
data InfectiousDisease = InfectiousDisease { infectiousAgent :: InfectiousAgent
                                           , infectiousAgentClass :: InfectiousAgentClass
                                           , transmissionMethod :: TransmissionMethod
                                           , associatedAnatomy :: AssociatedAnatomy
                                           , cause :: Cause
                                           , differentialDiagnosis :: DifferentialDiagnosis
                                           , epidemiology :: Epidemiology
                                           , expectedPrognosis :: ExpectedPrognosis
                                           , naturalProgression :: NaturalProgression
                                           , pathophysiology :: Pathophysiology
                                           , possibleComplication :: PossibleComplication
                                           , possibleTreatment :: PossibleTreatment
                                           , primaryPrevention :: PrimaryPrevention
                                           , riskFactor :: RiskFactor
                                           , secondaryPrevention :: SecondaryPrevention
                                           , signOrSymptom :: SignOrSymptom
                                           , stage :: Stage
                                           , subtype :: Subtype
                                           , typicalTest :: TypicalTest
                                           , code :: Code
                                           , guideline :: Guideline
                                           , medicineSystem :: MedicineSystem
                                           , recognizingAuthority :: RecognizingAuthority
                                           , relevantSpecialty :: RelevantSpecialty
                                           , study :: Study
                                           , additionalType :: AdditionalType
                                           , alternateName :: AlternateName
                                           , description :: Description
                                           , image :: Image
                                           , mainEntityOfPage :: MainEntityOfPage
                                           , name :: Name
                                           , potentialAction :: PotentialAction
                                           , sameAs :: SameAs
                                           , url :: Url
                                           }
                         deriving (Show, Read, Eq, Typeable)

instance MetaData InfectiousDisease where
  _label         = const "Infectious Disease"
  _comment_plain = const "An infectious disease is a clinically evident human disease resulting from the presence of pathogenic microbial agents, like pathogenic viruses, pathogenic bacteria, fungi, protozoa, multicellular parasites, and prions. To be considered an infectious disease, such pathogens are known to be able to cause this disease."
  _comment       = const "An infectious disease is a clinically evident human disease resulting from the presence of pathogenic microbial agents, like pathogenic viruses, pathogenic bacteria, fungi, protozoa, multicellular parasites, and prions. To be considered an infectious disease, such pathogens are known to be able to cause this disease."
  _url           = const "http://schema.org/InfectiousDisease"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalCondition.MedicalCondition)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalCondition.MedicalCondition)]