{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Intangible where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AlignmentObject
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Audience
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Brand
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.BroadcastChannel
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.BusTrip
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Class
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.DataFeedItem
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Demand
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.EntryPoint
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Enumeration
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Flight
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.GameServer
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Invoice
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ItemList
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.JobPosting
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Language
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ListItem
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Offer
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Order
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.OrderItem
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ParcelDelivery
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Permit
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ProgramMembership
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Property
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PropertyValueSpecification
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Quantity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Rating
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Reservation
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Role
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Seat
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Service
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ServiceChannel
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.StructuredValue
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Ticket
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TrainTrip

-- | A utility class that serves as the umbrella for a number of 'intangible' things such as quantities, structured values, etc.
--
--   [@id@] Intangible
--
--   [@label@] Intangible
--
--   [@comment@] A utility class that serves as the umbrella for a number of 'intangible' things such as quantities, structured values, etc.
--
--   [@ancestors@] @'Thing'@
--
--   [@subtypes@] @'AlignmentObject','Audience','Brand','BroadcastChannel','BusTrip','Class','DataFeedItem','Demand','EntryPoint','Enumeration','Flight','GameServer','Invoice','ItemList','JobPosting','Language','ListItem','Offer','Order','OrderItem','ParcelDelivery','Permit','ProgramMembership','Property','PropertyValueSpecification','Quantity','Rating','Reservation','Role','Seat','Service','ServiceChannel','StructuredValue','Ticket','TrainTrip'@
--
--   [@supertypes@] @'Thing'@
--
--   [@url@] <http://schema.org/Intangible>
data Intangible = Intangible { additionalType :: AdditionalType
                             , alternateName :: AlternateName
                             , description :: Description
                             , image :: Image
                             , mainEntityOfPage :: MainEntityOfPage
                             , name :: Name
                             , potentialAction :: PotentialAction
                             , sameAs :: SameAs
                             , url :: Url
                             }
                  deriving (Show, Read, Eq, Typeable)

instance MetaData Intangible where
  _label         = const "Intangible"
  _comment_plain = const "A utility class that serves as the umbrella for a number of 'intangible' things such as quantities, structured values, etc."
  _comment       = const "A utility class that serves as the umbrella for a number of 'intangible' things such as quantities, structured values, etc."
  _url           = const "http://schema.org/Intangible"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.AlignmentObject.AlignmentObject)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Audience.Audience)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Brand.Brand)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.BroadcastChannel.BroadcastChannel)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.BusTrip.BusTrip)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Class.Class)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.DataFeedItem.DataFeedItem)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Demand.Demand)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.EntryPoint.EntryPoint)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Enumeration.Enumeration)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Flight.Flight)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.GameServer.GameServer)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Invoice.Invoice)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ItemList.ItemList)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.JobPosting.JobPosting)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Language.Language)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ListItem.ListItem)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Offer.Offer)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Order.Order)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.OrderItem.OrderItem)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ParcelDelivery.ParcelDelivery)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Permit.Permit)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ProgramMembership.ProgramMembership)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Property.Property)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PropertyValueSpecification.PropertyValueSpecification)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Quantity.Quantity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Rating.Rating)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Reservation.Reservation)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Role.Role)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Seat.Seat)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Service.Service)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ServiceChannel.ServiceChannel)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.StructuredValue.StructuredValue)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Ticket.Ticket)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TrainTrip.TrainTrip)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)]