{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Landform where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.BodyOfWater
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Continent
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Mountain
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Volcano

-- | A landform or physical feature.  Landform elements include mountains, plains, lakes, rivers, seascape and oceanic waterbody interface features such as bays, peninsulas, seas and so forth, including sub-aqueous terrain features such as submersed mountain ranges, volcanoes, and the great ocean basins.
--
--   [@id@] Landform
--
--   [@label@] Landform
--
--   [@comment@] A landform or physical feature.  Landform elements include mountains, plains, lakes, rivers, seascape and oceanic waterbody interface features such as bays, peninsulas, seas and so forth, including sub-aqueous terrain features such as submersed mountain ranges, volcanoes, and the great ocean basins.
--
--   [@ancestors@] @'Thing','Place'@
--
--   [@subtypes@] @'BodyOfWater','Continent','Mountain','Volcano'@
--
--   [@supertypes@] @'Place'@
--
--   [@url@] <http://schema.org/Landform>
data Landform = Landform { additionalProperty :: AdditionalProperty
                         , address :: Address
                         , aggregateRating :: AggregateRating
                         , branchCode :: BranchCode
                         , containedInPlace :: ContainedInPlace
                         , containsPlace :: ContainsPlace
                         , event :: Event
                         , faxNumber :: FaxNumber
                         , geo :: Geo
                         , globalLocationNumber :: GlobalLocationNumber
                         , hasMap :: HasMap
                         , isicV4 :: IsicV4
                         , logo :: Logo
                         , openingHoursSpecification :: OpeningHoursSpecification
                         , photo :: Photo
                         , review :: Review
                         , telephone :: Telephone
                         , additionalType :: AdditionalType
                         , alternateName :: AlternateName
                         , description :: Description
                         , image :: Image
                         , mainEntityOfPage :: MainEntityOfPage
                         , name :: Name
                         , potentialAction :: PotentialAction
                         , sameAs :: SameAs
                         , url :: Url
                         }
                deriving (Show, Read, Eq, Typeable)

instance MetaData Landform where
  _label         = const "Landform"
  _comment_plain = const "A landform or physical feature.  Landform elements include mountains, plains, lakes, rivers, seascape and oceanic waterbody interface features such as bays, peninsulas, seas and so forth, including sub-aqueous terrain features such as submersed mountain ranges, volcanoes, and the great ocean basins."
  _comment       = const "A landform or physical feature.  Landform elements include mountains, plains, lakes, rivers, seascape and oceanic waterbody interface features such as bays, peninsulas, seas and so forth, including sub-aqueous terrain features such as submersed mountain ranges, volcanoes, and the great ocean basins."
  _url           = const "http://schema.org/Landform"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.BodyOfWater.BodyOfWater)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Continent.Continent)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Mountain.Mountain)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Volcano.Volcano)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)]