{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.LocalBusiness where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Organization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LocalBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Place
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AnimalShelter
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AutomotiveBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ChildCare
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.DryCleaningOrLaundry
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.EmergencyService
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.EmploymentAgency
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.EntertainmentBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.FinancialService
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.FoodEstablishment
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.GovernmentOffice
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.HealthAndBeautyBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.HomeAndConstructionBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.InternetCafe
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LegalService
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Library
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.LodgingBusiness
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalOrganization
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ProfessionalService
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.RadioStation
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.RealEstateAgent
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.RecyclingCenter
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.SelfStorage
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ShoppingCenter
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.SportsActivityLocation
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Store
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TelevisionStation
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TouristInformationCenter
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TravelAgency

-- | A particular physical business or branch of an organization. Examples of LocalBusiness include a restaurant, a particular branch of a restaurant chain, a branch of a bank, a medical practice, a club, a bowling alley, etc.
--
--   [@id@] LocalBusiness
--
--   [@label@] Local Business
--
--   [@comment@] A particular physical business or branch of an organization. Examples of LocalBusiness include a restaurant, a particular branch of a restaurant chain, a branch of a bank, a medical practice, a club, a bowling alley, etc.
--
--   [@ancestors@] @'Thing','Organization','LocalBusiness','Thing','Place'@
--
--   [@subtypes@] @'AnimalShelter','AutomotiveBusiness','ChildCare','DryCleaningOrLaundry','EmergencyService','EmploymentAgency','EntertainmentBusiness','FinancialService','FoodEstablishment','GovernmentOffice','HealthAndBeautyBusiness','HomeAndConstructionBusiness','InternetCafe','LegalService','Library','LodgingBusiness','MedicalOrganization','ProfessionalService','RadioStation','RealEstateAgent','RecyclingCenter','SelfStorage','ShoppingCenter','SportsActivityLocation','Store','TelevisionStation','TouristInformationCenter','TravelAgency'@
--
--   [@supertypes@] @'Organization','Place'@
--
--   [@url@] <http://schema.org/LocalBusiness>
data LocalBusiness = LocalBusiness { branchCode :: BranchCode
                                   , currenciesAccepted :: CurrenciesAccepted
                                   , openingHours :: OpeningHours
                                   , paymentAccepted :: PaymentAccepted
                                   , priceRange :: PriceRange
                                   , address :: Address
                                   , aggregateRating :: AggregateRating
                                   , alumni :: Alumni
                                   , areaServed :: AreaServed
                                   , award :: Award
                                   , brand :: Brand
                                   , contactPoint :: ContactPoint
                                   , department :: Department
                                   , dissolutionDate :: DissolutionDate
                                   , duns :: Duns
                                   , email :: Email
                                   , employee :: Employee
                                   , event :: Event
                                   , faxNumber :: FaxNumber
                                   , founder :: Founder
                                   , foundingDate :: FoundingDate
                                   , foundingLocation :: FoundingLocation
                                   , globalLocationNumber :: GlobalLocationNumber
                                   , hasOfferCatalog :: HasOfferCatalog
                                   , hasPOS :: HasPOS
                                   , isicV4 :: IsicV4
                                   , legalName :: LegalName
                                   , location :: Location
                                   , logo :: Logo
                                   , makesOffer :: MakesOffer
                                   , member :: Member
                                   , memberOf :: MemberOf
                                   , naics :: Naics
                                   , numberOfEmployees :: NumberOfEmployees
                                   , owns :: Owns
                                   , parentOrganization :: ParentOrganization
                                   , review :: Review
                                   , seeks :: Seeks
                                   , subOrganization :: SubOrganization
                                   , taxID :: TaxID
                                   , telephone :: Telephone
                                   , vatID :: VatID
                                   , additionalProperty :: AdditionalProperty
                                   , containedInPlace :: ContainedInPlace
                                   , containsPlace :: ContainsPlace
                                   , geo :: Geo
                                   , hasMap :: HasMap
                                   , openingHoursSpecification :: OpeningHoursSpecification
                                   , photo :: Photo
                                   , additionalType :: AdditionalType
                                   , alternateName :: AlternateName
                                   , description :: Description
                                   , image :: Image
                                   , mainEntityOfPage :: MainEntityOfPage
                                   , name :: Name
                                   , potentialAction :: PotentialAction
                                   , sameAs :: SameAs
                                   , url :: Url
                                   }
                     deriving (Show, Read, Eq, Typeable)

instance MetaData LocalBusiness where
  _label         = const "Local Business"
  _comment_plain = const "A particular physical business or branch of an organization. Examples of LocalBusiness include a restaurant, a particular branch of a restaurant chain, a branch of a bank, a medical practice, a club, a bowling alley, etc."
  _comment       = const "A particular physical business or branch of an organization. Examples of LocalBusiness include a restaurant, a particular branch of a restaurant chain, a branch of a bank, a medical practice, a club, a bowling alley, etc."
  _url           = const "http://schema.org/LocalBusiness"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LocalBusiness.LocalBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.AnimalShelter.AnimalShelter)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.AutomotiveBusiness.AutomotiveBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ChildCare.ChildCare)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.DryCleaningOrLaundry.DryCleaningOrLaundry)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.EmergencyService.EmergencyService)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.EmploymentAgency.EmploymentAgency)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.EntertainmentBusiness.EntertainmentBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.FinancialService.FinancialService)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.FoodEstablishment.FoodEstablishment)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.GovernmentOffice.GovernmentOffice)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.HealthAndBeautyBusiness.HealthAndBeautyBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.HomeAndConstructionBusiness.HomeAndConstructionBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.InternetCafe.InternetCafe)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LegalService.LegalService)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Library.Library)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.LodgingBusiness.LodgingBusiness)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalOrganization.MedicalOrganization)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ProfessionalService.ProfessionalService)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.RadioStation.RadioStation)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.RealEstateAgent.RealEstateAgent)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.RecyclingCenter.RecyclingCenter)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.SelfStorage.SelfStorage)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ShoppingCenter.ShoppingCenter)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.SportsActivityLocation.SportsActivityLocation)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Store.Store)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TelevisionStation.TelevisionStation)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TouristInformationCenter.TouristInformationCenter)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TravelAgency.TravelAgency)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Organization.Organization)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Place.Place)]