{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.MedicalGuidelineContraindication where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalGuideline

-- | A guideline contraindication that designates a process as harmful and where quality of the data supporting the contraindication is sound.
--
--   [@id@] MedicalGuidelineContraindication
--
--   [@label@] Medical Guideline Contraindication
--
--   [@comment@] A guideline contraindication that designates a process as harmful and where quality of the data supporting the contraindication is sound.
--
--   [@ancestors@] @'Thing','MedicalEntity','MedicalGuideline'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'MedicalGuideline'@
--
--   [@url@] <http://schema.org/MedicalGuidelineContraindication>
data MedicalGuidelineContraindication = MedicalGuidelineContraindication { evidenceLevel :: EvidenceLevel
                                                                         , evidenceOrigin :: EvidenceOrigin
                                                                         , guidelineDate :: GuidelineDate
                                                                         , guidelineSubject :: GuidelineSubject
                                                                         , code :: Code
                                                                         , guideline :: Guideline
                                                                         , medicineSystem :: MedicineSystem
                                                                         , recognizingAuthority :: RecognizingAuthority
                                                                         , relevantSpecialty :: RelevantSpecialty
                                                                         , study :: Study
                                                                         , additionalType :: AdditionalType
                                                                         , alternateName :: AlternateName
                                                                         , description :: Description
                                                                         , image :: Image
                                                                         , mainEntityOfPage :: MainEntityOfPage
                                                                         , name :: Name
                                                                         , potentialAction :: PotentialAction
                                                                         , sameAs :: SameAs
                                                                         , url :: Url
                                                                         }
                                        deriving (Show, Read, Eq, Typeable)

instance MetaData MedicalGuidelineContraindication where
  _label         = const "Medical Guideline Contraindication"
  _comment_plain = const "A guideline contraindication that designates a process as harmful and where quality of the data supporting the contraindication is sound."
  _comment       = const "A guideline contraindication that designates a process as harmful and where quality of the data supporting the contraindication is sound."
  _url           = const "http://schema.org/MedicalGuidelineContraindication"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalGuideline.MedicalGuideline)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalGuideline.MedicalGuideline)]