{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.MedicalRiskEstimator where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalRiskCalculator
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalRiskScore

-- | Any rule set or interactive tool for estimating the risk of developing a complication or condition.
--
--   [@id@] MedicalRiskEstimator
--
--   [@label@] Medical Risk Estimator
--
--   [@comment@] Any rule set or interactive tool for estimating the risk of developing a complication or condition.
--
--   [@ancestors@] @'Thing','MedicalEntity'@
--
--   [@subtypes@] @'MedicalRiskCalculator','MedicalRiskScore'@
--
--   [@supertypes@] @'MedicalEntity'@
--
--   [@url@] <http://schema.org/MedicalRiskEstimator>
data MedicalRiskEstimator = MedicalRiskEstimator { estimatesRiskOf :: EstimatesRiskOf
                                                 , includedRiskFactor :: IncludedRiskFactor
                                                 , code :: Code
                                                 , guideline :: Guideline
                                                 , medicineSystem :: MedicineSystem
                                                 , recognizingAuthority :: RecognizingAuthority
                                                 , relevantSpecialty :: RelevantSpecialty
                                                 , study :: Study
                                                 , additionalType :: AdditionalType
                                                 , alternateName :: AlternateName
                                                 , description :: Description
                                                 , image :: Image
                                                 , mainEntityOfPage :: MainEntityOfPage
                                                 , name :: Name
                                                 , potentialAction :: PotentialAction
                                                 , sameAs :: SameAs
                                                 , url :: Url
                                                 }
                            deriving (Show, Read, Eq, Typeable)

instance MetaData MedicalRiskEstimator where
  _label         = const "Medical Risk Estimator"
  _comment_plain = const "Any rule set or interactive tool for estimating the risk of developing a complication or condition."
  _comment       = const "Any rule set or interactive tool for estimating the risk of developing a complication or condition."
  _url           = const "http://schema.org/MedicalRiskEstimator"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalRiskCalculator.MedicalRiskCalculator)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalRiskScore.MedicalRiskScore)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)]