{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.MedicalRiskFactor where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MedicalEntity

-- | A risk factor is anything that increases a person's likelihood of developing or contracting a disease, medical condition, or complication.
--
--   [@id@] MedicalRiskFactor
--
--   [@label@] Medical Risk Factor
--
--   [@comment@] A risk factor is anything that increases a person's likelihood of developing or contracting a disease, medical condition, or complication.
--
--   [@ancestors@] @'Thing','MedicalEntity'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'MedicalEntity'@
--
--   [@url@] <http://schema.org/MedicalRiskFactor>
data MedicalRiskFactor = MedicalRiskFactor { increasesRiskOf :: IncreasesRiskOf
                                           , code :: Code
                                           , guideline :: Guideline
                                           , medicineSystem :: MedicineSystem
                                           , recognizingAuthority :: RecognizingAuthority
                                           , relevantSpecialty :: RelevantSpecialty
                                           , study :: Study
                                           , additionalType :: AdditionalType
                                           , alternateName :: AlternateName
                                           , description :: Description
                                           , image :: Image
                                           , mainEntityOfPage :: MainEntityOfPage
                                           , name :: Name
                                           , potentialAction :: PotentialAction
                                           , sameAs :: SameAs
                                           , url :: Url
                                           }
                         deriving (Show, Read, Eq, Typeable)

instance MetaData MedicalRiskFactor where
  _label         = const "Medical Risk Factor"
  _comment_plain = const "A risk factor is anything that increases a person's likelihood of developing or contracting a disease, medical condition, or complication."
  _comment       = const "A risk factor is anything that increases a person's likelihood of developing or contracting a disease, medical condition, or complication."
  _url           = const "http://schema.org/MedicalRiskFactor"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MedicalEntity.MedicalEntity)]