{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.OpeningHoursSpecification where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type hiding (OpeningHoursSpecification)
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.StructuredValue

-- | A structured value providing information about the opening hours of a place or a certain service inside a place.
--
--   [@id@] OpeningHoursSpecification
--
--   [@label@] Opening Hours Specification
--
--   [@comment@] A structured value providing information about the opening hours of a place or a certain service inside a place.
--
--   [@ancestors@] @'Thing','Intangible','StructuredValue'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'StructuredValue'@
--
--   [@url@] <http://schema.org/OpeningHoursSpecification>
data OpeningHoursSpecification = OpeningHoursSpecification { closes :: Closes
                                                           , dayOfWeek :: DayOfWeek
                                                           , opens :: Opens
                                                           , validFrom :: ValidFrom
                                                           , validThrough :: ValidThrough
                                                           , additionalType :: AdditionalType
                                                           , alternateName :: AlternateName
                                                           , description :: Description
                                                           , image :: Image
                                                           , mainEntityOfPage :: MainEntityOfPage
                                                           , name :: Name
                                                           , potentialAction :: PotentialAction
                                                           , sameAs :: SameAs
                                                           , url :: Url
                                                           }
                                 deriving (Show, Read, Eq, Typeable)

instance MetaData OpeningHoursSpecification where
  _label         = const "Opening Hours Specification"
  _comment_plain = const "A structured value providing information about the opening hours of a place or a certain service inside a place."
  _comment       = const "A structured value providing information about the opening hours of a place or a certain service inside a place."
  _url           = const "http://schema.org/OpeningHoursSpecification"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.StructuredValue.StructuredValue)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.StructuredValue.StructuredValue)]