{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.OrganizationRole where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Role
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.EmployeeRole

-- | A subclass of Role used to describe roles within organizations.
--
--   [@id@] OrganizationRole
--
--   [@label@] Organization Role
--
--   [@comment@] A subclass of Role used to describe roles within organizations.
--
--   [@ancestors@] @'Thing','Intangible','Role'@
--
--   [@subtypes@] @'EmployeeRole'@
--
--   [@supertypes@] @'Role'@
--
--   [@url@] <http://schema.org/OrganizationRole>
data OrganizationRole = OrganizationRole { numberedPosition :: NumberedPosition
                                         , endDate :: EndDate
                                         , roleName :: RoleName
                                         , startDate :: StartDate
                                         , additionalType :: AdditionalType
                                         , alternateName :: AlternateName
                                         , description :: Description
                                         , image :: Image
                                         , mainEntityOfPage :: MainEntityOfPage
                                         , name :: Name
                                         , potentialAction :: PotentialAction
                                         , sameAs :: SameAs
                                         , url :: Url
                                         }
                        deriving (Show, Read, Eq, Typeable)

instance MetaData OrganizationRole where
  _label         = const "Organization Role"
  _comment_plain = const "A subclass of Role used to describe roles within organizations."
  _comment       = const "A subclass of Role used to describe roles within organizations."
  _url           = const "http://schema.org/OrganizationRole"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Role.Role)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.EmployeeRole.EmployeeRole)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Role.Role)]