{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.OwnershipInfo where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.StructuredValue

-- | A structured value providing information about when a certain organization or person owned a certain product.
--
--   [@id@] OwnershipInfo
--
--   [@label@] Ownership Info
--
--   [@comment@] A structured value providing information about when a certain organization or person owned a certain product.
--
--   [@ancestors@] @'Thing','Intangible','StructuredValue'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'StructuredValue'@
--
--   [@url@] <http://schema.org/OwnershipInfo>
data OwnershipInfo = OwnershipInfo { acquiredFrom :: AcquiredFrom
                                   , ownedFrom :: OwnedFrom
                                   , ownedThrough :: OwnedThrough
                                   , typeOfGood :: TypeOfGood
                                   , additionalType :: AdditionalType
                                   , alternateName :: AlternateName
                                   , description :: Description
                                   , image :: Image
                                   , mainEntityOfPage :: MainEntityOfPage
                                   , name :: Name
                                   , potentialAction :: PotentialAction
                                   , sameAs :: SameAs
                                   , url :: Url
                                   }
                     deriving (Show, Read, Eq, Typeable)

instance MetaData OwnershipInfo where
  _label         = const "Ownership Info"
  _comment_plain = const "A structured value providing information about when a certain organization or person owned a certain product."
  _comment       = const "A structured value providing information about when a certain organization or person owned a certain product."
  _url           = const "http://schema.org/OwnershipInfo"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.StructuredValue.StructuredValue)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.StructuredValue.StructuredValue)]