{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ParentAudience where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Audience
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.PeopleAudience

-- | A set of characteristics describing parents, who can be interested in viewing some content.
--
--   [@id@] ParentAudience
--
--   [@label@] Parent Audience
--
--   [@comment@] A set of characteristics describing parents, who can be interested in viewing some content.
--
--   [@ancestors@] @'Thing','Intangible','Audience','PeopleAudience'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'PeopleAudience'@
--
--   [@url@] <http://schema.org/ParentAudience>
data ParentAudience = ParentAudience { childMaxAge :: ChildMaxAge
                                     , childMinAge :: ChildMinAge
                                     , healthCondition :: HealthCondition
                                     , requiredGender :: RequiredGender
                                     , requiredMaxAge :: RequiredMaxAge
                                     , requiredMinAge :: RequiredMinAge
                                     , suggestedGender :: SuggestedGender
                                     , suggestedMaxAge :: SuggestedMaxAge
                                     , suggestedMinAge :: SuggestedMinAge
                                     , audienceType :: AudienceType
                                     , geographicArea :: GeographicArea
                                     , additionalType :: AdditionalType
                                     , alternateName :: AlternateName
                                     , description :: Description
                                     , image :: Image
                                     , mainEntityOfPage :: MainEntityOfPage
                                     , name :: Name
                                     , potentialAction :: PotentialAction
                                     , sameAs :: SameAs
                                     , url :: Url
                                     }
                      deriving (Show, Read, Eq, Typeable)

instance MetaData ParentAudience where
  _label         = const "Parent Audience"
  _comment_plain = const "A set of characteristics describing parents, who can be interested in viewing some content."
  _comment       = const "A set of characteristics describing parents, who can be interested in viewing some content."
  _url           = const "http://schema.org/ParentAudience"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Audience.Audience)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.PeopleAudience.PeopleAudience)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.PeopleAudience.PeopleAudience)]