{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.QuantitativeValue where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.StructuredValue

-- | A point value or interval for product characteristics and other purposes.
--
--   [@id@] QuantitativeValue
--
--   [@label@] Quantitative Value
--
--   [@comment@]  A point value or interval for product characteristics and other purposes.
--
--   [@ancestors@] @'Thing','Intangible','StructuredValue'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'StructuredValue'@
--
--   [@url@] <http://schema.org/QuantitativeValue>
data QuantitativeValue = QuantitativeValue { additionalProperty :: AdditionalProperty
                                           , maxValue :: MaxValue
                                           , minValue :: MinValue
                                           , unitCode :: UnitCode
                                           , unitText :: UnitText
                                           , value :: Value
                                           , valueReference :: ValueReference
                                           , additionalType :: AdditionalType
                                           , alternateName :: AlternateName
                                           , description :: Description
                                           , image :: Image
                                           , mainEntityOfPage :: MainEntityOfPage
                                           , name :: Name
                                           , potentialAction :: PotentialAction
                                           , sameAs :: SameAs
                                           , url :: Url
                                           }
                         deriving (Show, Read, Eq, Typeable)

instance MetaData QuantitativeValue where
  _label         = const "Quantitative Value"
  _comment_plain = const "A point value or interval for product characteristics and other purposes."
  _comment       = const " A point value or interval for product characteristics and other purposes."
  _url           = const "http://schema.org/QuantitativeValue"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.StructuredValue.StructuredValue)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.StructuredValue.StructuredValue)]