{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ReplaceAction where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.UpdateAction

-- | The act of editing a recipient by replacing an old object with a new object.
--
--   [@id@] ReplaceAction
--
--   [@label@] Replace Action
--
--   [@comment@] The act of editing a recipient by replacing an old object with a new object.
--
--   [@ancestors@] @'Thing','Action','UpdateAction'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'UpdateAction'@
--
--   [@url@] <http://schema.org/ReplaceAction>
data ReplaceAction = ReplaceAction { replacee :: Replacee
                                   , replacer :: Replacer
                                   , targetCollection :: TargetCollection
                                   , actionStatus :: ActionStatus
                                   , agent :: Agent
                                   , endTime :: EndTime
                                   , error :: Error
                                   , instrument :: Instrument
                                   , location :: Location
                                   , object :: Object
                                   , participant :: Participant
                                   , result :: Result
                                   , startTime :: StartTime
                                   , target :: Target
                                   , additionalType :: AdditionalType
                                   , alternateName :: AlternateName
                                   , description :: Description
                                   , image :: Image
                                   , mainEntityOfPage :: MainEntityOfPage
                                   , name :: Name
                                   , potentialAction :: PotentialAction
                                   , sameAs :: SameAs
                                   , url :: Url
                                   }
                     deriving (Show, Read, Eq, Typeable)

instance MetaData ReplaceAction where
  _label         = const "Replace Action"
  _comment_plain = const "The act of editing a recipient by replacing an old object with a new object."
  _comment       = const "The act of editing a recipient by replacing an old object with a new object."
  _url           = const "http://schema.org/ReplaceAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.UpdateAction.UpdateAction)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.UpdateAction.UpdateAction)]