{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.ResumeAction where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ControlAction

-- | The act of resuming a device or application which was formerly paused (e.g. resume music playback or resume a timer).
--
--   [@id@] ResumeAction
--
--   [@label@] Resume Action
--
--   [@comment@] The act of resuming a device or application which was formerly paused (e.g. resume music playback or resume a timer).
--
--   [@ancestors@] @'Thing','Action','ControlAction'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'ControlAction'@
--
--   [@url@] <http://schema.org/ResumeAction>
data ResumeAction = ResumeAction { actionStatus :: ActionStatus
                                 , agent :: Agent
                                 , endTime :: EndTime
                                 , error :: Error
                                 , instrument :: Instrument
                                 , location :: Location
                                 , object :: Object
                                 , participant :: Participant
                                 , result :: Result
                                 , startTime :: StartTime
                                 , target :: Target
                                 , additionalType :: AdditionalType
                                 , alternateName :: AlternateName
                                 , description :: Description
                                 , image :: Image
                                 , mainEntityOfPage :: MainEntityOfPage
                                 , name :: Name
                                 , potentialAction :: PotentialAction
                                 , sameAs :: SameAs
                                 , url :: Url
                                 }
                    deriving (Show, Read, Eq, Typeable)

instance MetaData ResumeAction where
  _label         = const "Resume Action"
  _comment_plain = const "The act of resuming a device or application which was formerly paused (e.g. resume music playback or resume a timer)."
  _comment       = const "The act of resuming a device or application which was formerly paused (e.g. resume music playback or resume a timer)."
  _url           = const "http://schema.org/ResumeAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ControlAction.ControlAction)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.ControlAction.ControlAction)]