{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.Seat where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible

-- | Used to describe a seat, such as a reserved seat in an event reservation.
--
--   [@id@] Seat
--
--   [@label@] Seat
--
--   [@comment@] Used to describe a seat, such as a reserved seat in an event reservation.
--
--   [@ancestors@] @'Thing','Intangible'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Intangible'@
--
--   [@url@] <http://schema.org/Seat>
data Seat = Seat { seatNumber :: SeatNumber
                 , seatRow :: SeatRow
                 , seatSection :: SeatSection
                 , seatingType :: SeatingType
                 , additionalType :: AdditionalType
                 , alternateName :: AlternateName
                 , description :: Description
                 , image :: Image
                 , mainEntityOfPage :: MainEntityOfPage
                 , name :: Name
                 , potentialAction :: PotentialAction
                 , sameAs :: SameAs
                 , url :: Url
                 }
            deriving (Show, Read, Eq, Typeable)

instance MetaData Seat where
  _label         = const "Seat"
  _comment_plain = const "Used to describe a seat, such as a reserved seat in an event reservation."
  _comment       = const "Used to describe a seat, such as a reserved seat in an event reservation."
  _url           = const "http://schema.org/Seat"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)]