{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.SoftwareApplication where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CreativeWork
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.MobileApplication
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.VideoGame
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.WebApplication

-- | A software application.
--
--   [@id@] SoftwareApplication
--
--   [@label@] Software Application
--
--   [@comment@] A software application.
--
--   [@ancestors@] @'Thing','CreativeWork'@
--
--   [@subtypes@] @'MobileApplication','VideoGame','WebApplication'@
--
--   [@supertypes@] @'CreativeWork'@
--
--   [@url@] <http://schema.org/SoftwareApplication>
data SoftwareApplication = SoftwareApplication { applicationCategory :: ApplicationCategory
                                               , applicationSubCategory :: ApplicationSubCategory
                                               , applicationSuite :: ApplicationSuite
                                               , availableOnDevice :: AvailableOnDevice
                                               , countriesNotSupported :: CountriesNotSupported
                                               , countriesSupported :: CountriesSupported
                                               , downloadUrl :: DownloadUrl
                                               , featureList :: FeatureList
                                               , fileSize :: FileSize
                                               , installUrl :: InstallUrl
                                               , memoryRequirements :: MemoryRequirements
                                               , operatingSystem :: OperatingSystem
                                               , permissions :: Permissions
                                               , processorRequirements :: ProcessorRequirements
                                               , releaseNotes :: ReleaseNotes
                                               , screenshot :: Screenshot
                                               , softwareAddOn :: SoftwareAddOn
                                               , softwareHelp :: SoftwareHelp
                                               , softwareRequirements :: SoftwareRequirements
                                               , softwareVersion :: SoftwareVersion
                                               , storageRequirements :: StorageRequirements
                                               , supportingData :: SupportingData
                                               , about :: About
                                               , accessibilityAPI :: AccessibilityAPI
                                               , accessibilityControl :: AccessibilityControl
                                               , accessibilityFeature :: AccessibilityFeature
                                               , accessibilityHazard :: AccessibilityHazard
                                               , accountablePerson :: AccountablePerson
                                               , aggregateRating :: AggregateRating
                                               , alternativeHeadline :: AlternativeHeadline
                                               , associatedMedia :: AssociatedMedia
                                               , audience :: Audience
                                               , audio :: Audio
                                               , author :: Author
                                               , award :: Award
                                               , character :: Character
                                               , citation :: Citation
                                               , comment :: Comment
                                               , commentCount :: CommentCount
                                               , contentLocation :: ContentLocation
                                               , contentRating :: ContentRating
                                               , contributor :: Contributor
                                               , copyrightHolder :: CopyrightHolder
                                               , copyrightYear :: CopyrightYear
                                               , creator :: Creator
                                               , dateCreated :: DateCreated
                                               , dateModified :: DateModified
                                               , datePublished :: DatePublished
                                               , discussionUrl :: DiscussionUrl
                                               , editor :: Editor
                                               , educationalAlignment :: EducationalAlignment
                                               , educationalUse :: EducationalUse
                                               , encoding :: Encoding
                                               , exampleOfWork :: ExampleOfWork
                                               , fileFormat :: FileFormat
                                               , genre :: Genre
                                               , hasPart :: HasPart
                                               , headline :: Headline
                                               , inLanguage :: InLanguage
                                               , interactionStatistic :: InteractionStatistic
                                               , interactivityType :: InteractivityType
                                               , isBasedOnUrl :: IsBasedOnUrl
                                               , isFamilyFriendly :: IsFamilyFriendly
                                               , isPartOf :: IsPartOf
                                               , keywords :: Keywords
                                               , learningResourceType :: LearningResourceType
                                               , license :: License
                                               , locationCreated :: LocationCreated
                                               , mainEntity :: MainEntity
                                               , mentions :: Mentions
                                               , offers :: Offers
                                               , position :: Position
                                               , producer :: Producer
                                               , provider :: Provider
                                               , publication :: Publication
                                               , publisher :: Publisher
                                               , publishingPrinciples :: PublishingPrinciples
                                               , recordedAt :: RecordedAt
                                               , releasedEvent :: ReleasedEvent
                                               , review :: Review
                                               , schemaVersion :: SchemaVersion
                                               , sourceOrganization :: SourceOrganization
                                               , text :: Text
                                               , thumbnailUrl :: ThumbnailUrl
                                               , timeRequired :: TimeRequired
                                               , translator :: Translator
                                               , typicalAgeRange :: TypicalAgeRange
                                               , version :: Version
                                               , video :: Video
                                               , workExample :: WorkExample
                                               , additionalType :: AdditionalType
                                               , alternateName :: AlternateName
                                               , description :: Description
                                               , image :: Image
                                               , mainEntityOfPage :: MainEntityOfPage
                                               , name :: Name
                                               , potentialAction :: PotentialAction
                                               , sameAs :: SameAs
                                               , url :: Url
                                               }
                           deriving (Show, Read, Eq, Typeable)

instance MetaData SoftwareApplication where
  _label         = const "Software Application"
  _comment_plain = const "A software application."
  _comment       = const "A software application."
  _url           = const "http://schema.org/SoftwareApplication"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CreativeWork.CreativeWork)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.MobileApplication.MobileApplication)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.VideoGame.VideoGame)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.WebApplication.WebApplication)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.CreativeWork.CreativeWork)]