{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.TVSeries where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CreativeWork
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.CreativeWorkSeries
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.TVSeries

-- | CreativeWorkSeries dedicated to TV broadcast and associated online delivery.
--
--   [@id@] TVSeries
--
--   [@label@] TV Series
--
--   [@comment@] CreativeWorkSeries dedicated to TV broadcast and associated online delivery.
--
--   [@ancestors@] @'Thing','CreativeWork','CreativeWorkSeries','TVSeries','Thing','CreativeWork'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'CreativeWorkSeries','CreativeWork'@
--
--   [@url@] <http://schema.org/TVSeries>
data TVSeries = TVSeries { actor :: Actor
                         , containsSeason :: ContainsSeason
                         , countryOfOrigin :: CountryOfOrigin
                         , director :: Director
                         , episode :: Episode
                         , musicBy :: MusicBy
                         , numberOfEpisodes :: NumberOfEpisodes
                         , numberOfSeasons :: NumberOfSeasons
                         , productionCompany :: ProductionCompany
                         , trailer :: Trailer
                         , about :: About
                         , accessibilityAPI :: AccessibilityAPI
                         , accessibilityControl :: AccessibilityControl
                         , accessibilityFeature :: AccessibilityFeature
                         , accessibilityHazard :: AccessibilityHazard
                         , accountablePerson :: AccountablePerson
                         , aggregateRating :: AggregateRating
                         , alternativeHeadline :: AlternativeHeadline
                         , associatedMedia :: AssociatedMedia
                         , audience :: Audience
                         , audio :: Audio
                         , author :: Author
                         , award :: Award
                         , character :: Character
                         , citation :: Citation
                         , comment :: Comment
                         , commentCount :: CommentCount
                         , contentLocation :: ContentLocation
                         , contentRating :: ContentRating
                         , contributor :: Contributor
                         , copyrightHolder :: CopyrightHolder
                         , copyrightYear :: CopyrightYear
                         , creator :: Creator
                         , dateCreated :: DateCreated
                         , dateModified :: DateModified
                         , datePublished :: DatePublished
                         , discussionUrl :: DiscussionUrl
                         , editor :: Editor
                         , educationalAlignment :: EducationalAlignment
                         , educationalUse :: EducationalUse
                         , encoding :: Encoding
                         , exampleOfWork :: ExampleOfWork
                         , fileFormat :: FileFormat
                         , genre :: Genre
                         , hasPart :: HasPart
                         , headline :: Headline
                         , inLanguage :: InLanguage
                         , interactionStatistic :: InteractionStatistic
                         , interactivityType :: InteractivityType
                         , isBasedOnUrl :: IsBasedOnUrl
                         , isFamilyFriendly :: IsFamilyFriendly
                         , isPartOf :: IsPartOf
                         , keywords :: Keywords
                         , learningResourceType :: LearningResourceType
                         , license :: License
                         , locationCreated :: LocationCreated
                         , mainEntity :: MainEntity
                         , mentions :: Mentions
                         , offers :: Offers
                         , position :: Position
                         , producer :: Producer
                         , provider :: Provider
                         , publication :: Publication
                         , publisher :: Publisher
                         , publishingPrinciples :: PublishingPrinciples
                         , recordedAt :: RecordedAt
                         , releasedEvent :: ReleasedEvent
                         , review :: Review
                         , schemaVersion :: SchemaVersion
                         , sourceOrganization :: SourceOrganization
                         , text :: Text
                         , thumbnailUrl :: ThumbnailUrl
                         , timeRequired :: TimeRequired
                         , translator :: Translator
                         , typicalAgeRange :: TypicalAgeRange
                         , version :: Version
                         , video :: Video
                         , workExample :: WorkExample
                         , endDate :: EndDate
                         , startDate :: StartDate
                         , additionalType :: AdditionalType
                         , alternateName :: AlternateName
                         , description :: Description
                         , image :: Image
                         , mainEntityOfPage :: MainEntityOfPage
                         , name :: Name
                         , potentialAction :: PotentialAction
                         , sameAs :: SameAs
                         , url :: Url
                         }
                deriving (Show, Read, Eq, Typeable)

instance MetaData TVSeries where
  _label         = const "TV Series"
  _comment_plain = const "CreativeWorkSeries dedicated to TV broadcast and associated online delivery."
  _comment       = const "CreativeWorkSeries dedicated to TV broadcast and associated online delivery."
  _url           = const "http://schema.org/TVSeries"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CreativeWork.CreativeWork)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CreativeWorkSeries.CreativeWorkSeries)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.TVSeries.TVSeries)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CreativeWork.CreativeWork)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.CreativeWorkSeries.CreativeWorkSeries)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.CreativeWork.CreativeWork)]