{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.TaxiReservation where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Intangible
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Reservation

-- | A reservation for a taxi.
--
--   [@id@] TaxiReservation
--
--   [@label@] Taxi Reservation
--
--   [@comment@] A reservation for a taxi.
--
--   [@ancestors@] @'Thing','Intangible','Reservation'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'Reservation'@
--
--   [@url@] <http://schema.org/TaxiReservation>
data TaxiReservation = TaxiReservation { partySize :: PartySize
                                       , pickupLocation :: PickupLocation
                                       , pickupTime :: PickupTime
                                       , bookingTime :: BookingTime
                                       , broker :: Broker
                                       , modifiedTime :: ModifiedTime
                                       , priceCurrency :: PriceCurrency
                                       , programMembershipUsed :: ProgramMembershipUsed
                                       , provider :: Provider
                                       , reservationFor :: ReservationFor
                                       , reservationId :: ReservationId
                                       , reservationStatus :: ReservationStatus
                                       , reservedTicket :: ReservedTicket
                                       , totalPrice :: TotalPrice
                                       , underName :: UnderName
                                       , additionalType :: AdditionalType
                                       , alternateName :: AlternateName
                                       , description :: Description
                                       , image :: Image
                                       , mainEntityOfPage :: MainEntityOfPage
                                       , name :: Name
                                       , potentialAction :: PotentialAction
                                       , sameAs :: SameAs
                                       , url :: Url
                                       }
                       deriving (Show, Read, Eq, Typeable)

instance MetaData TaxiReservation where
  _label         = const "Taxi Reservation"
  _comment_plain = const "A reservation for a taxi."
  _comment       = const "A reservation for a taxi."
  _url           = const "http://schema.org/TaxiReservation"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Intangible.Intangible)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Reservation.Reservation)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Reservation.Reservation)]