{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.UpdateAction where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AddAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.DeleteAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ReplaceAction

-- | The act of managing by changing/editing the state of the object.
--
--   [@id@] UpdateAction
--
--   [@label@] Update Action
--
--   [@comment@] The act of managing by changing/editing the state of the object.
--
--   [@ancestors@] @'Thing','Action'@
--
--   [@subtypes@] @'AddAction','DeleteAction','ReplaceAction'@
--
--   [@supertypes@] @'Action'@
--
--   [@url@] <http://schema.org/UpdateAction>
data UpdateAction = UpdateAction { targetCollection :: TargetCollection
                                 , actionStatus :: ActionStatus
                                 , agent :: Agent
                                 , endTime :: EndTime
                                 , error :: Error
                                 , instrument :: Instrument
                                 , location :: Location
                                 , object :: Object
                                 , participant :: Participant
                                 , result :: Result
                                 , startTime :: StartTime
                                 , target :: Target
                                 , additionalType :: AdditionalType
                                 , alternateName :: AlternateName
                                 , description :: Description
                                 , image :: Image
                                 , mainEntityOfPage :: MainEntityOfPage
                                 , name :: Name
                                 , potentialAction :: PotentialAction
                                 , sameAs :: SameAs
                                 , url :: Url
                                 }
                    deriving (Show, Read, Eq, Typeable)

instance MetaData UpdateAction where
  _label         = const "Update Action"
  _comment_plain = const "The act of managing by changing/editing the state of the object."
  _comment       = const "The act of managing by changing/editing the state of the object."
  _url           = const "http://schema.org/UpdateAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)]
  _subtypes      = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.AddAction.AddAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.DeleteAction.DeleteAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ReplaceAction.ReplaceAction)]
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)]