{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE DeriveDataTypeable #-}
module Text.HTML5.MetaData.Schema.WantAction where

--  Valid: 2016-03-21 (Schema.rdfs.org)

import Text.HTML5.MetaData.Class
import Text.HTML5.MetaData.Type
import Data.Text
import Data.Typeable
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Thing
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.Action
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.AssessAction
import {-# SOURCE #-} qualified Text.HTML5.MetaData.Schema.ReactAction

-- | The act of expressing a desire about the object. An agent wants an object.
--
--   [@id@] WantAction
--
--   [@label@] Want Action
--
--   [@comment@] The act of expressing a desire about the object. An agent wants an object.
--
--   [@ancestors@] @'Thing','Action','AssessAction','ReactAction'@
--
--   [@subtypes@]
--
--   [@supertypes@] @'ReactAction'@
--
--   [@url@] <http://schema.org/WantAction>
data WantAction = WantAction { actionStatus :: ActionStatus
                             , agent :: Agent
                             , endTime :: EndTime
                             , error :: Error
                             , instrument :: Instrument
                             , location :: Location
                             , object :: Object
                             , participant :: Participant
                             , result :: Result
                             , startTime :: StartTime
                             , target :: Target
                             , additionalType :: AdditionalType
                             , alternateName :: AlternateName
                             , description :: Description
                             , image :: Image
                             , mainEntityOfPage :: MainEntityOfPage
                             , name :: Name
                             , potentialAction :: PotentialAction
                             , sameAs :: SameAs
                             , url :: Url
                             }
                  deriving (Show, Read, Eq, Typeable)

instance MetaData WantAction where
  _label         = const "Want Action"
  _comment_plain = const "The act of expressing a desire about the object. An agent wants an object."
  _comment       = const "The act of expressing a desire about the object. An agent wants an object."
  _url           = const "http://schema.org/WantAction"
  _ancestors     = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.Thing.Thing)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.Action.Action)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.AssessAction.AssessAction)
                         ,typeOf (undefined :: Text.HTML5.MetaData.Schema.ReactAction.ReactAction)]
  _subtypes      = const []
  _supertypes    = const [typeOf (undefined :: Text.HTML5.MetaData.Schema.ReactAction.ReactAction)]